@@ -227,7 +227,7 @@ void check_i2c_interface(void){
 	}
 }
 
-void main(void)
+int main(void)
 {
 	char out_buf[20+1];
 	measured_val[0]=0;
@@ -312,5 +312,6 @@ void main(void)
 			}
 		}
 	}
+	return(0);
 }
 
